# Datasets

Import scvi-tools as:

```
import scvi
```

```{eval-rst}
.. currentmodule:: scvi

```

## Built in data

Here we host some published datasets that are useful for benchmarking and testing models.

```{eval-rst}
.. autosummary::
   :toctree: reference/
   :nosignatures:

   data.cellxgene
   data.pbmc_seurat_v4_cite_seq
   data.spleen_lymph_cite_seq
   data.heart_cell_atlas_subsampled
   data.pbmcs_10x_cite_seq
   data.purified_pbmc_dataset
   data.dataset_10x
   data.brainlarge_dataset
   data.pbmc_dataset
   data.cortex
   data.smfish
   data.synthetic_iid
   data.breast_cancer_dataset
   data.mouse_ob_dataset
   data.retina
   data.prefrontalcortex_starmap
   data.frontalcortex_dropseq
```
